@@ -4,6 +4,8 @@ function publish() {
   local binary
   binary="${1}"
 
+  echo "=> About to publish ""${binary}"
+
   if [ ! -e "${binary}" ];
   then
       echo 'Invalid binary ('"${binary}"')'
@@ -34,9 +36,16 @@ function publish() {
     jq -r '.[] | .tag_name' | \
     head -n1)"
 
+  if [ "$( echo -n "${binary}" | grep -c 'cli' )"  != "0" ];
+  then
+      release_name="$(echo -n "${release_name}" | sed -E 's/-backend/-cli/g')"
+  fi
+
+  echo '=> Release name is '"${release_name}"
+
   curl \
     -X POST \
-    --data-binary @${binary} \
+    --data-binary @"${binary}" \
     -H 'Content-Type: application/octet-stream' \
     -H "Authorization: Bearer ${GITHUB_TOKEN}" \
     "${upload_url}?name=${release_name}-linux"
@@ -49,4 +58,5 @@ function publish() {
     "${upload_url}?name=${release_name}-linux.sha256sum"
 }
 
-publish "${GITHUB_WORKSPACE}"'/'"${RELEASE_NAME}"
\ No newline at end of file
+publish "${GITHUB_WORKSPACE}"'/'"${RELEASE_NAME}"
+publish "${GITHUB_WORKSPACE}"'/'"${CLI_RELEASE_NAME}"
\ No newline at end of file
