@@ -6,7 +6,12 @@ pub use follow_up::container_exists;
 pub use follow_up::inspect_container_status;
 pub use follow_up::tail_container_logs;
 pub use removal::remove_existing_container;
+
+pub use start::program_fuzzing_cmd_provider;
 pub use start::program_verification_cmd_provider;
 pub use start::source_code_restoration_cmd_provider;
 pub use start::start_container;
+pub use start::stop_container;
+pub use start::uploaded_sources_listing_cmd_provider;
+
 pub use start::TARGET_RVT_DIRECTORY;
