@@ -1,14 +1,17 @@
-use crate::infrastructure::verification::runtime::docker::DockerContainerAPIClient;
+use crate::infrastructure as infra;
 use anyhow::Result;
 use bollard::container::{InspectContainerOptions, ListContainersOptions, LogOutput, LogsOptions};
 use bollard::models::*;
 use bollard::Docker;
 use color_eyre::{eyre::eyre, Report};
 use futures::stream::StreamExt;
+use infra::display::output;
+use infra::verification::runtime::docker::DockerContainerAPIClient;
+use regex::Regex;
 use std::collections::HashMap;
 use std::default::Default;
 use std::str;
-use tracing::{debug, info};
+use tracing::debug;
 
 pub async fn container_exists(
     container_api_client: &DockerContainerAPIClient<Docker>,
@@ -60,18 +63,29 @@ pub async fn tail_container_logs<'a>(
     while let Some(Ok(log)) = logs_stream.next().await {
         match log {
             LogOutput::StdOut { message } => {
-                let message = str::from_utf8(&*message).unwrap();
-                info!("[STDOUT] {}", message);
-                logs.push(String::from(message))
+                let message = str::from_utf8(&*message)?;
+                let re = Regex::new(r"^STDERR:.+")?;
+                let running_test = Regex::new(r"^Running\s.+")?;
+
+                if running_test.is_match(message) {
+                    output::print("{}{}", vec!["\n", message], Some(true));
+                    logs.push(format!("{}{}", "\n", String::from(message)));
+                } else if re.is_match(message) {
+                    output::print("{}", vec!["."], Some(true));
+                    logs.push(String::from("."));
+                } else {
+                    output::print("[STDOUT] {}", vec![message], Some(true));
+                    logs.push(String::from(message))
+                }
             }
             LogOutput::StdErr { message } => {
                 let message = str::from_utf8(&*message).unwrap();
-                info!("[STDERR] {}", message);
+                output::eprint("[STDERR] {}", vec![message], Some(true));
                 logs.push(String::from(message))
             }
             LogOutput::Console { message } => {
                 let message = str::from_utf8(&*message).unwrap();
-                info!("[CONSOLE] {}", message);
+                output::print("[CONSOLE] {}", vec![message], Some(true));
                 logs.push(String::from(message))
             }
             _ => {}
